@@ -19,6 +19,8 @@
 #
 # Contributor(s):
 #   Tarek Ziade (tarek@mozilla.com)
+#   Richard Newman (rnewman@mozilla.com)
+#   Rob Miller (rmiller@mozilla.com)
 #
 # Alternatively, the contents of this file may be used under the terms of
 # either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -51,7 +53,7 @@ REPO_ROOT = 'https://hg.mozilla.org/services/'
 PYTHON = sys.executable
 PIP = os.path.join(os.path.dirname(PYTHON), 'pip')
 PYPI = 'http://pypi.python.org/simple'
-TAG_PREFIX = 'rpm-'
+TAG_PREFIX = os.environ.get('TAG_PREFIX', 'rpm-')
 PYPI2RPM = os.path.join(os.path.dirname(PYTHON), 'pypi2rpm.py')
 
 
@@ -62,19 +64,25 @@ def is_git():
 
 def _get_tags(prefix=TAG_PREFIX):
     if is_git():
-        cmd = 'git tag'
+        cmds = ['git tag']
     else:
-        cmd = 'hg tags'
+        cmds = ['hg tags', 'hg branches']
 
-    sub = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE)
-    output = sub.stdout.read().strip()
+    output = ''
+    for cmd in cmds:
+        sub = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE)
+        addl = sub.stdout.read().strip()
+        if addl:
+            if output:
+                output += '\n'
+            output += addl
     if output == '':
         return []
 
     tags = [tag_ for tag_ in
                 [line.split()[0] for line in
                  output.split('\n')]
-            if tag_.startswith(TAG_PREFIX)]
+            if tag_.startswith(prefix)]
     if is_git():
         tags.reverse()
 
@@ -96,7 +104,7 @@ def get_channel_tag(channel):
     tags = _get_tags()
 
     if len(tags) == 0:
-        print ('Could not find any rpm-* tag')
+        print ('Could not find any %s* tag' % TAG_PREFIX)
         sys.exit(0)
 
     # looking for the latest channel tag
@@ -208,7 +216,7 @@ def has_changes(timeout=5, verbose=False):
         code, out, err = run('git diff --exit-code', timeout, verbose)
         return code == 1
     else:
-        code, out, err = run('hg di', timeout, verbose)
+        code, out, err = run('hg diff', timeout, verbose)
         return out != ''
 
 
